@@ -1,12 +1,14 @@
 <?php
 // API endpoint for site creation with container readiness checking
-require_once '../libs/session_check.php';
+header('Content-Type: application/json');
+
+// Check API permission
+check_api_permission('sites');
+
 require_once '../libs/mysqlmgmt.php';
 require_once '../libs/docker-api.php';
 require_once '../libs/pdns-integration.php';
 
-header('Content-Type: application/json');
-
 if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
     http_response_code(405);
     echo json_encode(['success' => false, 'error' => 'Method not allowed']);
